==> core-1.70.0-sources.jar: software/amazon/awscdk/core/TokenComparison.java <==
package software.amazon.awscdk.core;

/**
 * An enum-like class that represents the result of comparing two Tokens.
 * <p>
 * The return type of {&#64;link Token.compareStrings}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-23T23:56:40.155Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.TokenComparison")
public class TokenComparison extends software.amazon.jsii.JsiiObject {

    protected TokenComparison(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TokenComparison(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        BOTH_UNRESOLVED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "BOTH_UNRESOLVED", software.amazon.awscdk.core.TokenComparison.class);
        DIFFERENT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "DIFFERENT", software.amazon.awscdk.core.TokenComparison.class);
        ONE_UNRESOLVED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "ONE_UNRESOLVED", software.amazon.awscdk.core.TokenComparison.class);
        SAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "SAME", software.amazon.awscdk.core.TokenComparison.class);
    }

    /**
     * This means both components are Tokens.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison BOTH_UNRESOLVED;

    /**
     * This means we're certain the two components are NOT Tokens, and different.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison DIFFERENT;

    /**
     * This means exactly one of the components is a Token.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison ONE_UNRESOLVED;

    /**
     * This means we're certain the two components are NOT Tokens, and identical.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison SAME;
}

==> core-1.71.0-sources.jar: software/amazon/awscdk/core/TokenComparison.java <==
package software.amazon.awscdk.core;

/**
 * An enum-like class that represents the result of comparing two Tokens.
 * <p>
 * The return type of {&#64;link Token.compareStrings}.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.14.0 (build 729554b)", date = "2020-10-29T17:33:57.000Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.TokenComparison")
public class TokenComparison extends software.amazon.jsii.JsiiObject {

    protected TokenComparison(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TokenComparison(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        BOTH_UNRESOLVED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "BOTH_UNRESOLVED", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.TokenComparison.class));
        DIFFERENT = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "DIFFERENT", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.TokenComparison.class));
        ONE_UNRESOLVED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "ONE_UNRESOLVED", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.TokenComparison.class));
        SAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.TokenComparison.class, "SAME", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.TokenComparison.class));
    }

    /**
     * This means both components are Tokens.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison BOTH_UNRESOLVED;

    /**
     * This means we're certain the two components are NOT Tokens, and different.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison DIFFERENT;

    /**
     * This means exactly one of the components is a Token.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison ONE_UNRESOLVED;

    /**
     * This means we're certain the two components are NOT Tokens, and identical.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.core.TokenComparison SAME;
}
